# plone.classicui

`plone.classicui` is a distribution for Plone 6.1 or later which comes with a basic Classic UI set of functionality.
This is similar to what you had when you installed the Plone package in Plone 6.0 and created a Classic UI Plone site.

The package does not contain page templates,
it only contains dependencies to other add-ons and configures Plone.
It can be used as an example for your own Classic UI based Plone distribution.
